@@ -1,5 +1,4 @@
 import itertools
-from threading import RLock
 from typing import ClassVar
 from typing import Optional
 from typing import Set
@@ -79,8 +78,9 @@ class RuntimeWorker(periodic.PeriodicService):
     _runtime_metrics = attr.ib(factory=RuntimeMetrics, repr=False)
     _services = attr.ib(type=Set[str], init=False, factory=set)
 
+    enabled = False
     _instance = None  # type: ClassVar[Optional[RuntimeWorker]]
-    _lock = RLock()
+    _lock = forksafe.Lock()
 
     def __attrs_post_init__(self):
         # type: () -> None
@@ -110,6 +110,7 @@ class RuntimeWorker(periodic.PeriodicService):
             cls._instance.stop()
             cls._instance.join()
             cls._instance = None
+            cls.enabled = False
 
     @classmethod
     def _restart(cls):
@@ -132,6 +133,7 @@ class RuntimeWorker(periodic.PeriodicService):
             forksafe.register(cls._restart)
 
             cls._instance = runtime_worker
+            cls.enabled = True
 
     def flush(self):
         # type: () -> None
@@ -144,12 +146,13 @@ class RuntimeWorker(periodic.PeriodicService):
         with self._dogstatsd_client:
             for key, value in self._runtime_metrics:
                 log.debug("Writing metric %s:%s", key, value)
-                self._dogstatsd_client.gauge(key, value)
+                self._dogstatsd_client.distribution(key, value)
 
-    def stop(self):
+    def _stop_service(self):  # type: ignore[override]
+        # type: (...) -> None
         # De-register span hook
+        super(RuntimeWorker, self)._stop_service()
         self.tracer.deregister_on_start_span(self._set_language_on_span)
-        super(RuntimeWorker, self).stop()
 
     def update_runtime_tags(self):
         # type: () -> None
